import { useState } from 'react';
import BubbleMap from './BubbleMap/index.js';
import { useWorldAtlas } from './hooks/useWorldAtlas';
import { useData } from './hooks/useData';
import { useCountryCodes } from './hooks/useCountryCodes';
import { config } from './config';



const App = () => {
  const [brushExtent, setBrushExtent] = useState(null);
  const { width, height, csvUrl, countriesJsonUrl,countryCodesUrl} = config;
  const { worldAtlas } = useWorldAtlas(countriesJsonUrl);
  const { data } = useData(csvUrl);
  const { countryCodes } = useCountryCodes(countryCodesUrl);
  
  const selectedYear = '2017';
  
  if (!worldAtlas || !data || !countryCodes) {
    return <pre>Loading...</pre>;
  }
	const filteredData = data.filter(d => d.Year === selectedYear);                    

  
  const histogramSizeRatio = 0.25;
  const histogramHeight = histogramSizeRatio * height;
  const mapHeight = height / 2;
  
  
  const rowByNumericCode = new Map();
  const numericCodeByAlphaCode = new Map();
  
  countryCodes.forEach(code => {
    const alpha3Code = code['alpha-3'];
    const numericCode = code['country-code'];
    numericCodeByAlphaCode.set(alpha3Code, numericCode); 
  })
  
  filteredData.forEach(d => {
    const alpha3Code = d.Code;
    const numericCode = numericCodeByAlphaCode.get(alpha3Code);
    rowByNumericCode.set(numericCode, d); 
  });
  
  console.log(rowByNumericCode)
  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(0, ${0})`}>
      	<BubbleMap mapData={worldAtlas} data={data} rowByNumericCode={rowByNumericCode} height={mapHeight} />
      </g>
    </svg>
  );
};

export default App;